=============
Cypress Point
=============


.. image:: https://img.shields.io/pypi/v/cypresspoint.svg
        :target: https://pypi.python.org/pypi/cypresspoint

.. image:: https://img.shields.io/travis/Kintyre/cypresspoint.svg
        :target: https://travis-ci.org/Kintyre/cypresspoint

.. image:: https://readthedocs.org/projects/cypresspoint/badge/?version=latest
        :target: https://cypresspoint.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/Kintyre/cypresspoint/shield.svg
     :target: https://pyup.io/repos/github/Kintyre/cypresspoint/
     :alt: Updates



Python helper bits for Splunk add-on development


* Free software: Apache Software License 2.0
* Documentation: https://cypresspoint.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
